@@ -221,10 +221,10 @@ class BatchLine(ModelSQL, ModelView):
     posting_text = fields.Char('Posting Text', states=_states,
             depends=_depends)
     batch = fields.Many2One('account.batch', 'Batch', ondelete='CASCADE',
-            domain=[('journal', '=', Eval('journal'))], states={
+            domain=[('journal', '=', Eval('journal', -1))], states={
                 'readonly': Or(
                     Equal(Eval('state'), 'posted'),
-                    Not(Bool(Eval('journal'))),
+                    Not(Bool(Eval('journal', -1))),
                     Bool(Get(Eval('context', {}), 'batch', 0))
                     )
             }, depends=['state', 'journal'], select=True)
@@ -232,14 +232,14 @@ class BatchLine(ModelSQL, ModelView):
             required=True, states={
                 'readonly': Or(
                     Equal(Eval('state'), 'posted'),
-                    Bool(Eval('journal')),
+                    Bool(Eval('journal', -1)),
                     Bool(Get(Eval('context', {}), 'journal', 0))
                     )
             }, depends=['state', 'journal'], select=True)
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
             states=_states, depends=_depends)
     date = fields.Date('Date', required=True, states={
-            'readonly': Or(Bool(Eval('move')),
+            'readonly': Or(Bool(Eval('move', -1)),
                 Bool(_states['readonly'])),
             },
         depends=_depends + ['move'], select=True)
@@ -313,7 +313,7 @@ class BatchLine(ModelSQL, ModelView):
             searcher='search_state')
     invoice = fields.Many2One('account.invoice', 'Invoice',
         domain=[
-            ('party', If(Bool(Eval('party')), '=', '!='), Eval('party')),
+            ('party', If(Bool(Eval('party', -1)), '=', '!='), Eval('party', -1)),
             ('state', 'in',
                 If(
                     In(Eval('state'), ['staging', 'draft']),
@@ -323,7 +323,7 @@ class BatchLine(ModelSQL, ModelView):
             ],
         states={
             'readonly':
-            Or(Bool(Eval('tax')),
+            Or(Bool(Eval('tax', -1)),
                 Or(
                     In(Get(Eval('_parent_batch', {}), 'journal_type'),
                         ['revenue', 'expense']),
@@ -339,16 +339,18 @@ class BatchLine(ModelSQL, ModelView):
         domain=[
             ('parent', '=', None),
             ['OR',
-                ('start_date', If(Eval('date'), '<=', '!='), Eval('date')),
+                ('start_date',
+                    If(Eval('date', None), '<=', '!='), Eval('date', None)),
                 ('start_date', '=', None),
                 ],
             ['OR',
-                ('end_date', If(Eval('date'), '>=', '!='), Eval('date')),
+                ('end_date',
+                    If(Eval('date', None), '>=', '!='), Eval('date', None)),
                 ('end_date', '=', None),
                 ],
             ],
         states={'readonly':
-                Or(Bool(Eval('invoice')),
+                Or(Bool(Eval('invoice', -1)),
                     _states['readonly'],
                 )
             },
@@ -564,15 +566,22 @@ class BatchLine(ModelSQL, ModelView):
                     and (not self.contra_account or not self.tax)
                     and self.amount):
                 type_ = self.journal.account_journal.type
+
+                account_payable = self.party.account_payable_used
+                payable_id = account_payable.id if account_payable else None
+                account_receivable = self.party.account_receivable_used
+                receivable_id = (
+                    account_receivable.id if account_receivable else None)
+
                 if type_ == 'expense':
-                    self.account = self.party.account_payable.id
+                    self.account = payable_id
                 elif type_ == 'revenue':
-                    self.account = self.party.account_receivable.id
+                    self.account = receivable_id
                 elif type_ in ['cash', 'bank']:
                     if self.amount >= _ZERO:
-                        self.contra_account = self.party.account_receivable.id
+                        self.contra_account = receivable_id
                     else:
-                        self.contra_account = self.party.account_payable.id
+                        self.contra_account = payable_id
             if not self.posting_text:
                 self.posting_text = self.party.rec_name
         else:
@@ -1278,23 +1287,21 @@ class OpenBatchJournalAsk(ModelView):
 
     batch_journal = fields.Many2One('account.batch.journal',
         'Batch Journal', required=True, states={
-            'readonly': Bool(Eval('batch')),
+            'readonly': Bool(Eval('batch', -1)),
             }, depends=['batch'])
     batch = fields.Many2One('account.batch', 'Batch', domain=[
-            ('journal', If(Bool(Eval('batch_journal')), '=', '!='),
-                Eval('batch_journal')),
+            ('journal', If(Bool(Eval('batch_journal', -1)), '=', '!='),
+                Eval('batch_journal', -1)),
             ('state', '=', 'open'),
             ], depends=['batch_journal'])
     show_draft = fields.Boolean('Show Draft')
     show_posted = fields.Boolean('Show Posted')
     period = fields.Many2One('account.period', 'Period', domain=[
-            ('fiscalyear', If(Bool(Eval('fiscalyear')), '=', '!='),
-                Eval('fiscalyear'))
+            ('fiscalyear', If(Bool(Eval('fiscalyear', -1)), '=', '!='),
+                Eval('fiscalyear', -1))
             ], depends=['fiscalyear'])
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscalyear')
-    company = fields.Many2One('company.company', 'Company', required=True,
-            domain=[('company', '=', Get(Eval('context', {}), 'company',
-                False))])
+    company = fields.Many2One('company.company', 'Company', required=True)
 
     @staticmethod
     def default_show_draft():
